Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type APIError ¶
type APIError struct {
Errors []string `json:"errors"`
}
APIError represents the container for errors from the bandsintown API
type Artist ¶
Artist represents core information about an Artist A component of ArtistInfo.go and Event.go
type ArtistEventSearchParam ¶
ArtistEventSearchParam is the parameter for the Artist Events api call https://www.bandsintown.com/api/1.0/requests#artists-events
type ArtistInfo ¶
ArtistInfo is the basic info for a single artist returned by the Artist get api call https://www.bandsintown.com/api/1.0/requests#artists-get
type Event ¶
type Event struct {
ID int `json:"id"`
URL string `json:"url"`
Datetime time.Time `json:"datetime"`
TicketURL string `json:"ticket_url"`
Artists []Artist `json:"artists"`
Venue Venue `json:"venue"`
Status string `json:"status"`
TicketStatus string `json:"ticket_status"`
OnSaleDatetime time.Time `json:"on_sale_datetime"`
}
Event respresent events, returned by the event service Has normal time.Time (RFC 3339) json serialisation
type EventOnSaleSoonParams ¶
type EventOnSaleSoonParams struct {
Location string `url:"location,omitempty"`
Radius int `url:"radius,omitempty"`
}
EventOnSaleSoonParams is the parameter for the Events On Sale Soon api call https://www.bandsintown.com/api/1.0/requests#events-on-sale-soon
type EventRecommendedParams ¶
type EventRecommendedParams struct {
EventSearchParams
OnlyRecommendations bool
}
EventRecommendedParams is the parameter for the Events Recommmended api call https://www.bandsintown.com/api/1.0/requests#events-recommended
type EventSearchParams ¶
type EventSearchParams struct {
Artists []string
Location string
Radius int
Date []time.Time
Page int
PerPage int
}
EventSearchParams is the parameter for the Events Search api call https://www.bandsintown.com/api/1.0/requests#events-search
type Venue ¶
type Venue struct {
ID int `json:"id"`
Name string `json:"name"`
City string `json:"city"`
Region string `json:"region"`
Country string `json:"country"`
URL string `json:"url"`
Latitude float64 `json:"latitude"`
Longitude float64 `json:"longitude"`
}
Venue represents a venue, returned by the Venue Search api call https://www.bandsintown.com/api/1.0/requests#venues-search
type VenueSearchParams ¶
VenueSearchParams is the parameter for the Venue Search api call https://www.bandsintown.com/api/1.0/requests#venues-search